pub struct GpuAoSoNormals { /* private fields */ }Expand description
GPU-resident (nx, ny, nz, curvature) output for AoSoA positions.
Implementations
Sourceimpl GpuAoSoNormals
impl GpuAoSoNormals
Sourcepub const fn point_count(&self) -> usize
pub const fn point_count(&self) -> usize
Returns the number of normal records.
Sourcepub fn recycle(self, runtime: &WgpuRuntime)
pub fn recycle(self, runtime: &WgpuRuntime)
Returns this output buffer to the runtime storage pool.
Sourcepub fn readback(&self, runtime: &WgpuRuntime) -> SpatialResult<Vec<GpuNormal>>
pub fn readback(&self, runtime: &WgpuRuntime) -> SpatialResult<Vec<GpuNormal>>
Reads normal and curvature records back to the CPU.