GpuVoxelSegments

Struct GpuVoxelSegments 

pub struct GpuVoxelSegments { /* private fields */ }
Voxel segment metadata kept on the GPU between sort/compact and reduce passes.

Implementations

Source

impl GpuVoxelSegments

pub fn cell_count(&self) -> u32

Returns the number of occupied voxel cells.

pub fn point_count(&self) -> u32

Returns the source point count represented by these segments.

pub fn keys_buffer(&self) -> &Buffer

Returns the GPU buffer of unique voxel keys.

pub fn point_indices_buffer(&self) -> &Buffer

Returns the GPU buffer of sorted point indices grouped by cell.

pub fn cell_starts_buffer(&self) -> &Buffer

Returns the GPU buffer of per-cell start offsets into point_indices.

pub fn to_voxel_segments( &self, runtime: &WgpuRuntime, ) -> SpatialResult<VoxelSegments>

Readbacks segment metadata into the CPU-side representation.